@@ -81,6 +81,7 @@ class List(object):
             self._size = int(args["size"])
             self._date_created = args.get("dateCreated")
             self._is_authorized = args.get("authorized")
+            self._status = args.get("status")
 
             if self._is_authorized is None: self._is_authorized = True
 
@@ -114,6 +115,11 @@ class List(object):
         """The fixed title of this list"""
         return self._title
 
+    @property
+    def status(self):
+        """The upgrade status of this list"""
+        return self._status
+
     @property
     def is_authorized(self):
         """Whether or not the current user is authorised to make changes to this list"""
